<?php
/**
 * admin.class.php
 *
 * This file contains class ES_Cookie_Notice_Admin_Pages that builds theme option pages
 * in the wp-admin
 *
 * @package Electric Studio Cookie Notice
 */

//check if class already exists
if( !class_exists( 'ES_Cookie_Notice_Admin_Pages' ) ) {
    /**
     *
     * Class for creating admin theme options
     * @author Luke <luke@electricstudio.co.uk>
     * @since 1.0
     */
	class ES_Cookie_Notice_Admin_Pages {

	    /**
	     *
	     * array of settings for the options
	     * @var 	array
	     * @since 	1.0
	     */
		protected $admin_page;

		/**
		 *
		 * array of fields to be used
		 * @var 	array
		 * @since	1.0
		 */
		protected $fields;

		/**
		 *
		 * array of sections to be used
		 * @var 	array
		 * @since	1.0
		 */
		protected $section;

		/**
		 *
		 * Construct
		 * @param 		array $admin_page
		 * @author		Luke <luke@electricstudio.co.uk>
		 * @since		1.0
		 */
		function __construct( $admin_page ) {
			// Make sure we are in the admin panel.
			if( !is_admin() )
				return;
			// Set the $admin_page property so we can access it within the class.
			$this->admin_page = $admin_page;
			$this->fields = $admin_page['fields'];
			$this->section = $admin_page['menu_slug'];
			// Hook the page onto the admin menu.
			add_action( 'admin_menu', array( &$this, 'add_page' ) );
			add_action('admin_init', array( &$this, 'register_theme_settings' ) );
		}

		/**
		 *
		 * Builds the page content
		 * @returns 	HTML
		 * @author		Luke <luke@electricstudio.co.uk>
		 * @since 		1.0
		 */
		function create_page_content() { ?>
			<div class="wrap">
				<?php
					// Give the user some response to the save action.
					settings_errors();
				?>
				<form action="options.php" method="post">
					<?php
						settings_fields( $this->admin_page['settings_section'] ); // Settings group.
						do_settings_sections( $this->admin_page['settings_section'] ); // Churn out the settings section Database options.
						submit_button(); // Add the submit button to the mix.
					?>
				</form>
			</div>
		<?php }

		/**
		 *
		 * HTML for a textbox field
		 * @param 		array $args
		 * @return 		HTML
		 * @author		Luke <luke@electricstudio.co.uk>
		 * @since		1.0
		 */
		function textbox_field( $args ) {
			$value = trim( $this->get_theme_options( $args['field_name'] ) );
			$std = isset( $args['field_std'] ) ? trim( $args['field_std'] ) : false;
			?>
			<input id="<?php echo $args['field_name']; ?>" name="<?php echo $this->admin_page['settings_name']; ?>[<?php echo $args['field_name']; ?>]" size='40' type='text' value="<?php if( !empty( $value ) ) {
				echo $value;
			} elseif( !empty( $std ) ) {
				echo $std;
			} ?>" class="regular-text" />
			<?php
				if( !empty( $args['field_desc'] ) )
					echo '<p class="description">' . $args['field_desc'] . '</p>';
			?>
		<?php }

		/**
		 *
		 * HTML for a number field
		 * @param 		array $args
		 * @return 		HTML
		 * @author		Luke <luke@electricstudio.co.uk>
		 * @since		1.0
		 */
		function number_field( $args ) {
			$value = trim( $this->get_theme_options( $args['field_name'] ) );
			$std = isset( $args['field_std'] ) ? trim( $args['field_std'] ) : false;
			?>
			<input id="<?php echo $args['field_name']; ?>" name="<?php echo $this->admin_page['settings_name']; ?>[<?php echo $args['field_name']; ?>]" size='10' type='number' value="<?php if( !empty( $value ) ) {
				echo $value;
			} elseif( !empty( $std ) ) {
				echo $std;
			} ?>" class="regular-text" />
			<?php
				if( !empty( $args['field_desc'] ) )
					echo '<p class="description">' . $args['field_desc'] . '</p>';
			?>
		<?php }

		/**
		 *
		 * HTML for a textarea field
		 * @param 		array $args
		 * @return 		HTML
		 * @author 		Luke <luke@electricstudio.co.uk>
		 * @since		1.0
		 */
		function textarea_field( $args ) {
			$value = trim( $this->get_theme_options( $args['field_name'] ) );
			$std 	= isset( $args['field_std'] ) ? trim( $args['field_std'] ) : false;
			?>
			<textarea id="<?php echo $args['field_name']; ?>" name="<?php echo $this->admin_page['settings_name']; ?>[<?php echo $args['field_name']; ?>]" rows="10" cols="50" class="large-text code"><?php
				if( !empty( $value ) )
					echo $value;
				elseif( !empty( $std ) )
					echo $std;
			?></textarea>
			<?php
				echo $this->get_theme_options( $args['field_name'] );
				if( !empty( $args['field_desc'] ) )
					echo '<p class="description">' . $args['field_desc'] . '</p>';
			?>
		<?php }

		/**
		 *
		 * HTML for a wysiwyg field
		 * @param 		array $args
		 * @return 		HTML
		 * @author		Luke <luke@electricstudio.co.uk>
		 * @since 		1.0
		 * @todo 		get this to work
		 */
		function wysiwyg_field( $args ) {
			$value 	= stripslashes( $this->get_theme_options( $args['field_name'] ) ); // Set the $content var up
			$std 	= isset( $args['field_std'] ) ? trim( $args['field_std'] ) : false;
			if( !empty( $value ) ) {
				$content = $value;
			}
			elseif( !empty( $std ) ) {
				$content = $std;
			}
			else {
				$content = "";
			}
			wp_editor( $content, $args['field_name'], array(
				'textarea_name' => $this->admin_page['settings_name'] . '[' .  $args['field_name'] . ']'
			) );
			if( !empty( $args['field_desc'] ) )
				echo '<p class="description">' . $args['field_desc'] . '</p>';
		}

		/**
		 *
		 * HTML for a radio field
		 * @param 		array $args
		 * @return 		HTML
		 * @author		Luke <luke@electricstudio.co.uk>
		 */
		function radio_field( $args ) {
			$max = count( $args['field_options'] );
			$i = 0;
			foreach( $args['field_options'] as $key => $value ) { $i += 1; ?>
				<label>
					<input type="radio" value="<?php echo $value; ?>" id="<?php echo $args['field_name']; ?>" name="<?php echo $this->admin_page['settings_name']; ?>[<?php echo $args['field_name']; ?>]" <?php if( $this->get_theme_options( $args['field_name'] ) == $value || $args['field_std'] == $value ) {
						echo 'checked="checked"';
					} ?> />
					<?php echo $key; ?>
				</label>
				<?php
				// Add a break after the radio buttons unless it is the last radio button.
				if( $i < $max ) {
					echo '<br />';
				}
				unset( $option );
				?>
			<?php }
			if( !empty( $args['field_desc'] ) )
				echo '<p class="description">' . $args['field_desc'] . '</p>';
		}

		/**
		 *
		 * HTML for a checkbox
		 * @param 		array $args
		 * @return 		HTML
		 * @author		Luke <luke@electricstudio.co.uk>
		 */
		function checkbox_field( $args ) {
			$max = count( $args['field_options'] );
			$i = 0;
			foreach( $args['field_options'] as $key => $value ) { $i += 1; ?>
				<label>
					<input type="checkbox" value="<?php echo $value; ?>" id="<?php echo $args['field_name']; ?>" name="<?php echo $this->admin_page['settings_name']; ?>[<?php echo $args['field_name']; ?>]" <?php if( $this->get_theme_options( $args['field_name'] ) == $value || $args['field_std'] == $value ) {
						echo 'checked="true"';
					} ?> />
					<?php echo $key; ?>
				</label>
				<?php
				// Add a break after the radio buttons unless it is the last radio button.
				if( $i < $max ) {
					echo '<br />';
				}
				unset( $option );
				?>
			<?php }
			if( !empty( $args['field_desc'] ) )
				echo '<p class="description">' . $args['field_desc'] . '</p>';
		}

		/**
		 *
		 * HTML for a listing the sites pages.
		 * @param 		array $args
		 * @return 		HTML
		 * @author		Luke <luke@electricstudio.co.uk>
		 * @since 		1.0
		 */
		function list_pages_field( $args ) {
			$pages = get_pages( array(
				'post_type' 	=> 'page',
    			'post_status' 	=> 'publish'
			) );
			$max = count( $pages );
			if( $max > 0 ) { ?>
				<select id="<?php echo $args['field_name']; ?>" name="<?php echo $this->admin_page['settings_name']; ?>[<?php echo $args['field_name']; ?>]">
					<option value="false"> -- Select page -- </option>
					<?php foreach( $pages as $page ) { ?>
						<option value="<?php echo $page->ID; ?>" <?php if( $this->get_theme_options( $args['field_name'] ) == $page->ID ) {
							echo 'selected="selected"';
						} ?>><?php echo $page->post_title; ?></option>
					<?php } ?>
				</select>
			<?php }
			if( !empty( $args['field_desc'] ) )
				echo '<p class="description">' . $args['field_desc'] . '</p>';
		}

		/**
		 *
		 * HTML for a subtitle text
		 * @return 		HTML
		 * @since 		1.0
		 * @author		Luke <luke@electricstudio.co.uk>
		 */
		function settings_description() { ?>
			<div class="es-plugin-header">
				<div class="es-row">
					<div class="es-col-2">
						<div id="escn-options" class="electric-studio-logo"><br /></div>
					</div>
					<div class="es-col-10">
						<h2><?php echo $this->admin_page['page_title']; ?></h2>
						<?php if( $this->admin_page['settings_desc'] ) { ?>
							<p><?php echo $this->admin_page['settings_desc']; ?></p>
						<?php } ?>
					</div>
				</div>
			</div>
		<?php }

        /**
         *
         * Get theme data
         * @param 		int $id
         * @return 		string/bool
         * @since 		1.0
         * @author		Luke <luke@electricstudio.co.uk>
         */
		function get_theme_options( $id ) {
			$options = get_option( $this->admin_page['settings_name'] );
			// Make a check to see if it exists first.
			if( !empty( $options[$id] ) )
				return stripslashes( trim( $options[$id] ) ); // Return the saved data.
			else
				return false; // Else just return false.
		}

		/**
		 *
		 * Registers theme options
		 * @author		Luke <luke@electricstudio.co.uk>
		 * @since 		1.0
		 */
		function register_theme_settings() {

			register_setting(
				$this->admin_page['settings_section'], // Store all settings under the $this->section var as an array.
				$this->admin_page['settings_name'] // Set the name of the options, all values will be saved in this array.
			);
			// Create the settings section.
			add_settings_section(
				$this->admin_page['settings_name'], // Set the unique ID of the section.
				false, // Set the title of the section.
				array( // Show the settings content in the section.
					&$this,
					'settings_description'
				),
				$this->admin_page['settings_section'] // This is the page name the settings section should appear on.
			);
			// Loop through the fields that have been defined and add them to the settings section.
			foreach ( $this->fields as $field ) {
				// Set up the callback array.
				$callback_args = array(
					'field_name' => $field['name'],
					'label_for' => $field['name']
				);
				// If there are options included in the $fields array merge the options into the $callback_args array.
				if( array_key_exists( 'options', $field ) )
					$callback_args = array_merge( $callback_args, array(
						'field_options' => $field['options']
					) );
				// If there is a description included in the $fields array merge the description in the $callback_args array.
				if( array_key_exists( 'desc', $field ) )
					$callback_args = array_merge( $callback_args, array(
						'field_desc' => $field['desc']
					) );
				// If there is a std included in the $fields array merge the description in the $callback_args array.
				if( array_key_exists( 'std', $field ) )
					$callback_args = array_merge( $callback_args, array(
						'field_std' => $field['std']
					) );
				// Create the settings field.
				add_settings_field(
					$field['name'], // Set the field name.
					$field['title'], // Set the field title.
					array(
						&$this,
						$field['type'] . '_field' // Pull through the field HTML.
					),
					$this->admin_page['settings_section'], // Add it to the page.
					$this->admin_page['settings_name'], // Add it to the settings section via the settings ID.
					$callback_args
				);
				unset( $callback_args, $option );
			}
		}

		/**
		 *
		 * Add the theme options page
		 * @since 	1.0
		 * @author Luke <luke@electricstudio.co.uk>
		 */
		function add_page() {

			// Create the page to house all the theme settings fields.
			add_options_page(
				$this->admin_page['page_title'], // Set the page title.
				$this->admin_page['menu_title'], // Set the menu title.
				$this->admin_page['capability'], // Set the capabilty level (only admins should be able to view).
				$this->admin_page['menu_slug'], // Set the menu slug.
				array( // Run a function to add content to the page.
					&$this,
					'create_page_content'
				)
			);

		}
	}
}
