<?php
/**
 * escn-admin.php
 *
 * @package Electric Studio Cookie Notice
 */

// Run a quick check to see if we are logged into the admin panel.
if( is_admin() ) {

	// Include the class that creates the admin fields
	require_once( ESCN_PLUGIN_PATH . 'admin/classes/admin.class.php' );

	// Create the array that stores the individual settings page information.
	$admin_pages = array();

	// Set up a new settings page as an array part.
	$admin_pages['escn_options'] = array(
		'page_title' => 'ES Cookie Notice Options',
		'menu_title' => 'ES Cookie Notice Options',
		'capability' => 'manage_options',
		'menu_slug' => 'escn_plugin_options',
		'settings_section' => 'escn_plugin_options_section',
		'settings_name' => escn_config( 'settings_name' ),
		'settings_desc' => 'Below are the options for customising the look and content of the ES Cookie Notice plugin.<br />If you have any questions regarding the usage of the plugin please <a href="http://www.electricstudio.co.uk/?p=1539">visit our website</a>',
		'fields' => array(
			// New textbox
			array(
				'type' => 'textbox',
				'name' => 'escn_title',
				'title' => '<strong>Cookie Notice Title</strong>',
				'std' => escn_config( 'title' )
			),
			// New WYSIWYG
			array(
				'type' => 'wysiwyg',
				'name' => 'escn_text',
				'title' => '<strong>Cookie Notice Text</strong>',
				'std' => escn_config( 'text' )
			),
			// New radio buttons
			array(
				'type' => 'radio',
				'name' => 'escn_include_stylesheet',
				'title' => '<strong>Include the default Cookie Notice stylesheet?</strong>',
				'options' => array(
					'Yes' => 'Y',
					'No' => 'N'
				),
				'std' => 'Y',
				'desc' => '<strong>Usage</strong>: Select "No" if you are going to style up the box to match you\'re site.'
			),

			// Set position
			array(
				'type' => 'radio',
				'name' => 'escn_position',
				'title' => '<strong>Where would you like to place the notice?</strong>',
				'options' => array(
					'Top of page' => 'top',
					'Bottom of page' => 'bottom'
				),
				'std' => 'top',
			),

			// Set max width
			array(
				'type' => 'number',
				'name' => 'escn_max_width',
				'title' => '<strong>Set max width</strong>',
				'std' => '100',
				'desc' => 'Set max width on content inside, if unset will be 100% otherwise enter value in px',
			),
			// Set text font size
			array(
				'type' => 'number',
				'name' => 'escn_heading_font_size',
				'title' => '<strong>Heading font size</strong>',
				'std' => '18',
				'desc' => 'Set cookie notice title font size',
			),

			// Set text font size
			array(
				'type' => 'number',
				'name' => 'escn_text_font_size',
				'title' => '<strong>Text font size</strong>',
				'std' => '14',
				'desc' => 'Set cookie notice text font size',
			),

			// Background colour picker
			array(
				'type' => 'textbox',
				'name' => 'escn_bg_color',
				'title' => '<strong>Background Color</strong>',
				'std' => '#323232',
				'desc' => 'Set cookie notice background color. Please enter HEX value. If you need to pick a colour, you can use <a target="_blank" href="https://htmlcolorcodes.com/color-picker/">this tool</a>.',
			),

			// Text colour picker
			array(
				'type' => 'textbox',
				'name' => 'escn_text_color',
				'title' => '<strong>Text Color</strong>',
				'std' => '#FFFFFF',
				'desc' => 'Set cookie notice text color. Please enter HEX value. If you need to pick a colour, you can use <a target="_blank" href="https://htmlcolorcodes.com/color-picker/">this tool</a>.',
			),

			// Button background colour picker
			array(
				'type' => 'textbox',
				'name' => 'escn_button_bg_color',
				'title' => '<strong>Button Background Color</strong>',
				'std' => '',
				'desc' => 'Set cookie notice button background color. If left empty will take on theme button style. Please enter HEX value. If you need to pick a colour, you can use <a target="_blank" href="https://htmlcolorcodes.com/color-picker/">this tool</a>.',
			),

			// Button text colour picker
			array(
				'type' => 'textbox',
				'name' => 'escn_button_text_color',
				'title' => '<strong>Button Text Color</strong>',
				'std' => '',
				'desc' => 'Set cookie notice button text color. If left empty will take on theme button style. Please enter HEX value. If you need to pick a colour, you can use <a target="_blank" href="https://htmlcolorcodes.com/color-picker/">this tool</a>.',
			),
			// New list pages
			array(
				'type' => 'list_pages',
				'name' => 'escn_page',
				'title' => '<strong>Cookie Notice Page Link</strong>',
				'desc' => '<strong>Usage</strong>: Select the page you want the "Find out more" link to redirect to.<br /><strong>Default</strong>: If you don\'t select a page no link will appear.'
			),

			// Close on scroll
			array(
				'type' => 'checkbox',
				'name' => 'escn_scroll',
				'title' => '<strong>Hide cookie notice after scrolling down page?</strong>',
				'options' => array(
					'Hide on scroll' => 'true',
				),
				'std' => 'false',
			),
		)
	);

	// Run a quick check to see if the ES_Admin_Pages class has been included in the functions.
	if( class_exists( 'ES_Cookie_Notice_Admin_Pages' ) ) {
		// Loop through the array and pass the data to the ES_Admin_Pages class.
		foreach( $admin_pages as $admin_page ) {
			new ES_Cookie_Notice_Admin_Pages( $admin_page );
		}
	}
}
