<?php
/**
 *
 * electric-studio-cookie-notice.php
 *
 * @package Electric Studio Cookie Notice
 *
 * Plugin Name: ES Cookie Notice
 * Plugin URI: http://www.electricstudio.co.uk/?p=1539
 * Description: The Electric Studio Cookie notice plugin adds a cookie notice to the top or bottom of the website which is displayed via AJAX. The notice will display once and will set a cookie for 730 days (2 years). The plugin can be configured in the Wordpress Admin Panel via <strong>Settings</strong> >> <strong>ES Cookie Notice Options</strong>.
 * Author: Electric Studio
 * Version: 2.2
 * Author URI: http://www.electricstudio.co.uk
 *
 */

// Define the plugin folder.
// You will notice that plugins_url() is used elsewhere, this is becuase when testing local with symbolic links the images/css/js throws up a 404.
define( 'ESCN_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

// Create a function to return some config data.
function escn_config ( $part = false ) {
	// If no part was passed exit the function.
	if( !$part )
		return;
	// Create the config array.
	$config = array(
		'settings_name' 	=> 'escn_plugin_options',
		'title' 			=> 'Cookies on the ' . get_bloginfo( 'name' ) . ' website',
		'text'				=> 'We use cookies to ensure that we give you the best experience on our website. If you continue without changing your settings, we\'ll assume that you are happy to receive all cookies on the ' . get_bloginfo( 'name' ) . ' website. However, if you would like to, you can change your cookie settings at any time.',
		'nonce_name'		=> 'cookie_nonce'
	);
	// Return the config array part.
	return $config[ $part ];
}

// Include the files that builds the admin fields.
require_once( ESCN_PLUGIN_PATH . 'admin/escn-admin.php' );

// Include the files that builds the admin fields.
require_once( ESCN_PLUGIN_PATH . 'ajax/escn-ajax.php' );

// Create the function that adds the scripts.
function escn_add_scripts () {
	if( !is_admin() ) {
		// Enqueue the script.
		wp_enqueue_script( 'escn_script', plugins_url( '/js/escn-functions.js', __FILE__ ), array( 'jquery' ), 1, true );
		// Create the javaScript config object.
		wp_localize_script( 'escn_script', 'ESCN_CONFIG', array(
			'admin_url' => admin_url( 'admin-ajax.php' ),
			'nonce'		=> wp_create_nonce( escn_config( 'nonce_name' ) )
		) );
	}
}
add_action( 'wp_enqueue_scripts', 'escn_add_scripts' );

// Create the function that adds the styles.
function escn_add_styles () {
	$options 		= get_option( escn_config( 'settings_name' ) );
	$include_style 	= $options['escn_include_stylesheet'];
	// Include the stylesheet
	wp_enqueue_style( 'escn_style', plugins_url( '/css/escn-styles.css', __FILE__ ), false, 1 );
	// If the user has set it to not appear, remove the stylesheet.
	if( $include_style && $include_style == 'N' ) {
		wp_deregister_style( 'escn_style' );
	}

}
add_action( 'wp_enqueue_scripts', 'escn_add_styles' );

// Create the function that adds the admin styles.
function escn_add_admin_styles () {
	wp_enqueue_style( 'escn_admin', plugins_url( '/css/escn-admin.css', __FILE__ ), false, 1 );
}
add_action( 'admin_head', 'escn_add_admin_styles' );
