/**
 *
 * escn-functions.js
 *
 * @package Electric Studio Cookie Notice
 *
 */
(function($) {

	/**
	 *
	 * Create an cookie class.
	 * @name 	Cookie()
	 * @return 	N/A
	 * @author 	Matt <matt@electricstudio.co.uk>
	 * @since	1.0
	 */
	var Cookie = {
		set: function(c_name, value, expiredays) {
	        var exdate = new Date();
	        exdate.setDate(exdate.getDate() + expiredays);
	        document.cookie = c_name + "=" + escape(value) + ((expiredays == null) ? "" : ";expires=" + exdate.toUTCString()+";path=/");
	    },
		get: function(c_name) {
	        if (document.cookie.length > 0) {
	            c_start = document.cookie.indexOf(c_name + "=");
	            if (c_start != -1) {
	                c_start = c_start + c_name.length + 1;
	                c_end = document.cookie.indexOf(";", c_start);
	                if (c_end == -1) c_end = document.cookie.length;
	                return unescape(document.cookie.substring(c_start, c_end));
	            }
	        }
	        return "";
		},
		erase: function(name){
			this.set(name, '', -1);
		}
	};

	var CookieNotice = function (opts) {
		this.init(opts);
	};
	CookieNotice.prototype = {
		removeNotice: function () {
			var self = this;
			$('#escn-continue').on('click', function (e) {
				self.container.animate({
					'height': 0
				}, function () {
					self.container.remove();
				} );
				e.preventDefault();
			});
		},
		setCookie: function () {
			var self = this;
			// Set the cookie notice so it won't appear for the next 24 hours.
			$('#escn-continue').on('click', function (e) {
				Cookie.set('escn-notice', true, 730);
			});
		},
		showContent: function () {
			// Find the inner container and it's height.
			var inner = this.container.find('.escn-inner'),
				height = inner.outerHeight(true),
				position = this.container.find('.escn-inner').attr('id'),
				style = this.container.find('.escn-inner').attr('data-background');

			$(window).resize(function() {
				$('.escn-outer').height('auto');
			});

			// Hide the content.
			this.container.css('background-color', style);
			this.container.addClass(position);
			inner.css('opacity', 0);
			// Animate the height of the container to the height of the content.
			this.container.removeClass('loading')
			.animate({
				'height': height
			});
			// Fade in the content.
			inner.animate({
				'opacity': 1
			});
			// Now give the user the option to acknowledge to cookie.
			this.setCookie();
		},
		cookieScroll: function () {
			var self = this;

			var inner = this.container.find('.escn-inner'),
				scroll = this.container.find('.escn-inner').attr('data-scroll');

			if(scroll == 'true') {
				var container = this.container,
					scrollCount = 0;

				$(window).scroll(function() {
					scrollCount++;
					if(scrollCount > 220) {
						self.container.animate({
							'height': 0
						}, function () {
							self.container.remove();
						} );
					}
				});
			}
		},
		setContent: function (content) {
			// Set the container content.
			this.container.html(content);

			// Then show the content.
			this.showContent();
			// Allow the users to remove the notice.
			this.removeNotice();
		},
		setContainer: function () {
			var self = this;
				this.container 	= $('<div>', {
					'id': 'cookie-notice',
					'class': 'escn-outer loading'
				});
			this.container.css({
				'height': 50
			})
			.prependTo('body');
		},
		getNotice: function () {
			var self = this;
			$.ajax({
				url: ESCN_CONFIG['admin_url'],
				type: 'post',
				data: {
					'action': 'escn_cookie_notice',
					'_ajax_nonce': ESCN_CONFIG['nonce']
				},
				beforeSend: function () {
					self.setContainer();
				},
				success: function (html) {
					self.setContent(html);
					self.cookieScroll();
				}
			});
		},
		init: function (opts) {
			this.opts 	= opts;
			this.cookie = ( Cookie.get( 'escn-notice' ) === "" || Cookie.get( 'escn-notice' ) === false ) ? false : true;
			if( this.cookie === false ) {
				this.getNotice();
			}

		}
	};
	var cookieNotice = new CookieNotice();
})(jQuery);
